import "./tasks/fastp.wdl" as fastp
import "./tasks/hisat2.wdl" as hisat2
import "./tasks/samtools.wdl" as samtools
import "./tasks/stringtie.wdl" as stringtie

workflow {{ project_name }} {

	String sample_id
	File read1
	File read2
        File idx
	String adapter_sequence
        String adapter_sequence_r2
	String idx_prefix
        File gtf
	
	call fastp.fastp as fastp {
        input:
		sample_id=sample_id, 
		read1=read1, 
		read2=read2, 
		adapter_sequence=adapter_sequence, 
		adapter_sequence_r2=adapter_sequence_r2
    }
	
	call hisat2.hisat2 as hisat2 {
	input: 
		sample_id=sample_id, 
		idx=idx, 
		idx_prefix=idx_prefix, 
		Trim_R1=fastp.Trim_R1, 
		Trim_R2=fastp.Trim_R2
	}

        call samtools.samtools as samtools {
               input: 
		sample_id=sample_id, 
		sam = hisat2.sam 
	}

        call stringtie.stringtie as stringtie {
              input: 
		gtf = gtf, 
		bam = samtools.out_bam ,
		sample_id=sample_id
	}
}


